package VMOMI::HostMountMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
